Description Details Note Author(s) Examples
Thanks to Funders, ...
sweepspecify
The most recent development version is available through GitHub by
running
devtools::install_github (repo = 'OuhscBbmc/sweepspecify')
(make sure devtools is already installed).
If you're having trouble with the package, please install the development version. If this doesn't solve
your problem, please create a new issue, or email Will.
William Howard Beasley, University of Oklahoma Health Sciences Center, College of Medicine, Dept of Pediatrics, BBMC.
Maintainer: Will Beasley wibeasley@hotmail.com
1 2 3 4 5 6 7 8 9 | ## Not run:
# Install/update sweepspecify with the release version from CRAN.
install.packages('sweepspecify') #But it's not on CRAN yet.
# Install/update sweepspecify with the development version from GitHub
#install.packages('devtools') #Uncomment if `devtools` isn't installed already.
devtools::install_github('OuhscBbmc/sweepspecify')
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.